module Bio
	module Pipengine
		
		# Step holds information for a pipeline step
		# groups_def is used to store information on groups definition (i.e. generic cmd lines with placeholders)
		# groups_cmd is used to store the actual command lines for all the samples to be combined in a "groups" step
		# this are generated by combining groups_def information with sample groups information and will be placed
		# where <groups> placeholder is found into the step command lines.
		class Step
			attr_accessor :name, :run, :cpus, :mem, :nodes, :multi_def, :multi_cmd, :pre
			def initialize(name,step_instructions)
				@name = name
				parse_yaml(step_instructions)	
			end

			def is_multi?
				return (self.multi_def.nil?) ? false : true
			end

			def has_prerequisite?
				return (self.pre.nil?) ? false : true
			end

			private

			def parse_yaml(step_instructions)
				self.cpus = step_instructions["cpu"].to_i
				self.nodes = step_instructions["nodes"]
				self.mem = step_instructions["mem"]
				self.run = step_instructions["run"]
				self.multi_def = step_instructions["multi"]
				self.pre = step_instructions["pre"]
			end

		end

	end
end

